#!/bin/bash

# Packager : Jean-Philippe Guillemin <jp.guillemin@free.fr>
# sources location : http://mocha.xfce.org/downloads/svn-snapshots



softversion='4.6.2'
packageversion='66.2'
softname='xfce-plugins'
arch='i486'
cpu='i686'

PKGBUILD=$(pwd)

package="$softname-$softversion-$arch-$packageversion"

PKG="/tmp/$package"
rm -rf $PKG
rm -f $PKG.tgz
mkdir -p $PKG

TMP="$PKGBUILD/tmp"

cd $PKGBUILD

sources="\
xfce4-xkb-plugin \
xfce4-battery-plugin \
xfce4-mailwatch-plugin \
xfce4-mount-plugin \
xfce4-fsguard-plugin \
xfce4-weather-plugin \
xfce4-netload-plugin \
xfce4-cpugraph-plugin \
xfce4-clipman-plugin \
xfce4-wavelan-plugin \
xfce4-places-plugin \
xfce4-quicklauncher-plugin \
thunar-media-tags-plugin \
xfce4-screenshooter \
xfce4-systemload-plugin "


for source in $sources ; do
  echo -n "Checking $source : "
  cd $PKGBUILD
  tarball="$(ls ${source}*tar* 2>/dev/null)"
  if [ "$tarball" == "" ] ; then
    echo "not found :("
    exit 1
  else
    echo "found $tarball :)"
  fi
done

for source in $sources ; do

  cd $PKGBUILD
  tarball="$(ls ${source}*tar* )"

  rm -rf $TMP
  mkdir -p $TMP
  
  if [ "$(echo $tarball | grep ".tar.bz2" )" ]; then
      tar jxvf $tarball -C $TMP
  elif [ "$(echo $tarball | grep ".tar.gz" )" ]; then
      tar zxvf $tarball -C $TMP
  fi
  
  SRC=$(ls -d $TMP/*/)

  
    cd $SRC
    
    chown -R root.root .
    find . -perm 777 -exec chmod 755 {} \;
    find . -perm 775 -exec chmod 755 {} \;
    find . -perm 666 -exec chmod 644 {} \;
    find . -perm 664 -exec chmod 644 {} \;
	[ "$source" == "xfce4-battery-plugin" ] && patch -p1 < $PKGBUILD/xfce4-battery-plugin-0.5.0.1-2.6.24.patch
    [ "$source" == "xfce4-places-plugin" ] && patch -p1 < $PKGBUILD/xfce4-places-plugin-trash_url_fix.patch
    [ "$source" == "xfce4-xkb-plugin" ] && patch -p1 < $PKGBUILD/xfce4-xkb-plugin-0.5.3.3-xklavier5.patch
   
    export CFLAGS="-Os -march=$arch -mtune=$cpu"
    export ICEAUTH='/usr/bin/iceauth'      
     ./configure --prefix=/usr \
      --mandir=/usr/man \
      --sysconfdir=/etc/X11 \
      --enable-static=no \
      --enable-compositor \
      --enable-xinerama \
      --enable-final \
      --enable-debug=no \
      --with-sound=alsa \
      --enable-maintainer-mode \
      --disable-gtk-doc
    
    make -j2 || exit 1
    # make install
    
    make install DESTDIR=$PKG
    
    mkdir -p $PKG/usr/doc/$(basename $SRC)
    cp -f AUTHORS INSTALL README TODO NEWS ChangeLog $PKG/usr/doc/$(basename $SRC)   

    # Striptease
    ( cd $PKG
      find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
      find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
      for mandir in $(find . -name man -type d) ; do
        if [ -d $mandir ]; then
          ( cd $mandir
            find . -type f -name "*.?" -exec gzip -9 {} \;
          )
        fi
      done
    )

done


cd $PKGBUILD


# Panel plugins Zenwalk desktop integration and fixes
mkdir -p $PKG/usr/share/xfce4/panel-plugins
  cp -pf ./panel-plugins/* $PKG/usr/share/xfce4/panel-plugins/


# redundant , if any
rm -rf $PKG/usr/share/doc

# slack-desc
mkdir -p $PKG/install
cat > $PKG/install/slack-desc << END
xfce-plugins: xfce-plugins - plugins for the XFCE desktop 
xfce-plugins:
xfce-plugins: XFce is a fast and lightweight desktop environment that is both
xfce-plugins: sex-appealing and easy to use.
xfce-plugins: For more information, see:  http://www.xfce.org
xfce-plugins:
xfce-plugins:
xfce-plugins:
xfce-plugins:
xfce-plugins:
xfce-plugins:
END

mkdir -p $PKG/usr/src/$softname-$softversion
cp $PKGBUILD/build-$softname.sh $PKG/usr/src/$softname-$softversion/
cp $PKGBUILD/*.patch $PKG/usr/src/$softname-$softversion/

cd $PKG
makepkg -l y -c n $PKG.txz

# Cleanup
cd $PKGBUILD
rm -rf $PKG
